@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # This file is part of Xpra.
-# Copyright (C) 2016-2023 Antoine Martin <antoine@xpra.org>
+# Copyright (C) 2016 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
@@ -104,7 +104,7 @@ class ServerTestUtil(ProcessTestUtil):
             "speaker", "microphone", "audio",
             "systemd-run", "start-via-proxy",
             "splash", "printing", "opengl",
-            "webcam", "bell", "system-tray", "notifications",
+            "webcam", "bell", "system-tray", "notification",
             "clipboard", "start-new-commands",
         ))
         defaults.update({
