@@ -5,41 +5,30 @@
 # later version. See the file COPYING for details.
 
 import ctypes
-import struct
 from weakref import WeakValueDictionary
 from typing import Any
 from collections.abc import Callable, Sequence
 
 import Quartz
-from Quartz import kCGDisplaySetModeFlag
 import Quartz.CoreGraphics as CG
-from Quartz.CoreGraphics import CGDisplayRegisterReconfigurationCallback, CGDisplayRemoveReconfigurationCallback
-from AppKit import NSObject, NSAppleEventManager, NSScreen, NSBeep, NSApp
+from AppKit import NSScreen, NSBeep, NSApp
 
 from xpra.os_util import gi_import
 from xpra.common import roundup
-from xpra.exit_codes import ExitValue
 from xpra.util.env import envint, envbool
 from xpra.util.io import CaptureStdErr
-from xpra.util.str_fn import bytestostr
 from xpra.platform.darwin import get_OSXApplication
 from xpra.log import Logger
 
 log = Logger("osx", "events")
 workspacelog = Logger("osx", "events", "workspace")
-mouselog = Logger("osx", "events", "mouse")
-notifylog = Logger("osx", "notify")
+pointerlog = Logger("osx", "events", "pointer")
 
-GLib = gi_import("GLib")
-
-OSX_FOCUS_WORKAROUND = envint("XPRA_OSX_FOCUS_WORKAROUND", 2000)
 SLEEP_HANDLER = envbool("XPRA_OSX_SLEEP_HANDLER", True)
-EVENT_LISTENER = envbool("XPRA_OSX_EVENT_LISTENER", True)
 OSX_WHEEL_MULTIPLIER = envint("XPRA_OSX_WHEEL_MULTIPLIER", 100)
 OSX_WHEEL_PRECISE_MULTIPLIER = envint("XPRA_OSX_WHEEL_PRECISE_MULTIPLIER", 1)
 OSX_WHEEL_DIVISOR = envint("XPRA_OSX_WHEEL_DIVISOR", 10)
 WHEEL = envbool("XPRA_WHEEL", True)
-NATIVE_NOTIFIER = envbool("XPRA_OSX_NATIVE_NOTIFIER", True)
 SUBPROCESS_NOTIFIER = envbool("XPRA_OSX_SUBPROCESS_NOTIFIER", False)
 
 ALPHA = {
@@ -96,29 +85,7 @@ def do_ready() -> None:
         osxapp.ready()
 
 
-def get_clipboard_native_class() -> str:
-    return "xpra.platform.darwin.clipboard.OSXClipboardProtocolHelper"
-
-
-def get_native_notifier_classes() -> list[type]:
-    v: list[type] = []
-    if NATIVE_NOTIFIER:
-        from Foundation import NSUserNotificationCenter
-        if NSUserNotificationCenter.defaultUserNotificationCenter():
-            from xpra.platform.darwin.notifier import OSX_Notifier
-            v.append(OSX_Notifier)
-    notifylog("get_native_notifier_classes()=%s", v)
-    return v
-
-
-def get_native_tray_menu_helper_class() -> Callable | None:
-    if get_OSXApplication():
-        from xpra.platform.darwin.menu import getOSXMenuHelper
-        return getOSXMenuHelper
-    return None
-
-
-def get_native_tray_classes() -> list[type]:
+def get_backends() -> list[type]:
     if get_OSXApplication():
         from xpra.platform.darwin.tray import OSXTray
         return [OSXTray]
@@ -216,6 +183,14 @@ def get_workareas() -> Sequence[tuple[int, int, int, int]]:
     return workareas
 
 
+def get_display_size() -> tuple[int, int]:
+    Gdk = gi_import("Gdk")
+    screen = Gdk.Screen.get_default
+    if not screen:
+        raise RuntimeError("unable to access the screen via Gdk")
+    return screen.get_width(), screen.get_height()
+
+
 def get_vrefresh() -> int:
     vrefresh = []
     try:
@@ -464,6 +439,7 @@ def take_screenshot() -> tuple[int, int, str, int, bytes]:
 
 def force_focus(duration=2000) -> None:
     enable_focus_workaround()
+    GLib = gi_import("GLib")
     GLib.timeout_add(duration, disable_focus_workaround)
 
 
@@ -474,37 +450,35 @@ __osx_open_signal = False
 OPEN_SIGNAL_WAIT = envint("XPRA_OSX_OPEN_SIGNAL_WAIT", 500)
 
 
-def add_open_handlers(open_file_cb: Callable, open_url_cb: Callable) -> None:
-
-    def open_URL(url) -> bool:
-        global __osx_open_signal
-        if __osx_open_signal:
-            return True
-        __osx_open_signal = True
-        log("open_URL(%s)", url)
-        GLib.idle_add(open_url_cb, bytestostr(url))
-        return True
-
-    def open_file(_, filename: str, *args) -> bool:
-        global __osx_open_signal
-        if __osx_open_signal:
-            return True
-        __osx_open_signal = True
-        log("open_file(%s, %s)", filename, args)
-        GLib.idle_add(open_file_cb, filename)
-        return True
-
-    register_file_handler(open_file)
-    register_URL_handler(open_URL)
-
-
-def wait_for_open_handlers(show_cb: Callable,
-                           open_file_cb: Callable,
-                           open_url_cb: Callable,
+def wait_for_open_handlers(show_cb: Callable[[], None],
+                           open_file_cb: Callable[[str], None],
+                           open_url_cb: Callable[[str], None],
                            delay: int = OPEN_SIGNAL_WAIT) -> None:
-    add_open_handlers(open_file_cb, open_url_cb)
+    GLib = gi_import("GLib")
 
-    def may_show():
+    def open_url(url: str) -> None:
+        global __osx_open_signal
+        if __osx_open_signal:
+            log.warn("Warning: open signal already handled, ignoring url %r", url)
+            return
+        __osx_open_signal = True
+        log("open_url(%s) will call %s", url, open_url_cb)
+        GLib.idle_add(open_url_cb, url)
+
+    def open_file(filename: str) -> None:
+        global __osx_open_signal
+        if __osx_open_signal:
+            log.warn("Warning: open signal already handled, ignoring file %r", filename)
+            return
+        __osx_open_signal = True
+        log("open_file(%s) will call %s", filename, open_file_cb)
+        GLib.idle_add(open_file_cb, filename)
+
+    from xpra.platform.darwin.events import get_app_delegate
+    get_app_delegate().set_url_handler(open_url)
+    get_app_delegate().set_file_handler(open_file)
+
+    def may_show() -> None:
         global __osx_open_signal
         log("may_show() osx open signal=%s", __osx_open_signal)
         if not __osx_open_signal:
@@ -512,44 +486,10 @@ def wait_for_open_handlers(show_cb: Callable,
             force_focus()
             show_cb()
 
+    log("waiting for open handlers or timeout in %ims", delay)
     GLib.timeout_add(delay, may_show)
 
 
-def register_file_handler(handler: Callable) -> None:
-    log("register_file_handler(%s)", handler)
-    try:
-        get_OSXApplication().connect("NSApplicationOpenFile", handler)
-    except Exception as e:
-        log.error("Error: cannot handle file associations:")
-        log.estr(e)
-
-
-def register_URL_handler(handler: Callable) -> None:
-    log("register_URL_handler(%s)", handler)
-
-    class GURLHandler(NSObject):
-        # noinspection PyMethodMayBeStatic
-        def handleEvent_withReplyEvent_(self, event, reply_event):
-            log("GURLHandler.handleEvent(%s, %s)", event, reply_event)
-            url = event.descriptorForKeyword_(four_char_to_int(b'----')).stringValue()
-            log("URL=%s", url)
-            handler(url.encode())
-
-    # A helper to make struct since cocoa headers seem to make
-    # it impossible to use kAE*
-    def four_char_to_int(code: bytes) -> int:
-        return struct.unpack(b'>l', code)[0]
-
-    urlh = GURLHandler.alloc()
-    urlh.init()
-    urlh.retain()
-    manager = NSAppleEventManager.sharedAppleEventManager()
-    manager.setEventHandler_andSelector_forEventClass_andEventID_(
-        urlh, 'handleEvent:withReplyEvent:',
-        four_char_to_int(b'GURL'), four_char_to_int(b'GURL')
-    )
-
-
 def disable_focus_workaround() -> None:
     NSApp.activateIgnoringOtherApps_(False)
 
@@ -574,123 +514,3 @@ def can_access_display() -> bool:
         # screen is locked
         return False
     return True
-
-
-class ClientExtras:
-    def __init__(self, client=None, opts=None):
-        if OSX_FOCUS_WORKAROUND and client:
-            def first_ui_received(*_args):
-                enable_focus_workaround()
-                GLib.timeout_add(OSX_FOCUS_WORKAROUND, disable_focus_workaround)
-
-            client.connect("first-ui-received", first_ui_received)
-        log("ClientExtras.__init__(%s, %s)", client, opts)
-        self.client = client
-        self.event_loop_started = False
-        self.check_display_timer = 0
-        self.display_is_asleep = False
-        if opts and client:
-            swap_keys = opts.swap_keys
-            log("setting swap_keys=%s using %s", swap_keys, client.keyboard_helper)
-            if client.keyboard_helper and client.keyboard_helper.keyboard:
-                log("%s.swap_keys=%s", client.keyboard_helper.keyboard, swap_keys)
-                client.keyboard_helper.keyboard.swap_keys = swap_keys
-        if client:
-            self.check_display_timer = GLib.timeout_add(60 * 1000, self.check_display)
-
-    def cleanup(self) -> None:
-        cdt = self.check_display_timer
-        if cdt:
-            GLib.source_remove(cdt)
-            self.check_display_timer = 0
-        try:
-            r = CGDisplayRemoveReconfigurationCallback(self.display_change, self)
-        except ValueError as e:
-            log("CGDisplayRemoveReconfigurationCallback: %s", e)
-            # if we exit from a signal, this may fail
-            r = 1
-        if r != 0:
-            # don't bother logging this as a warning since we are terminating anyway:
-            log("failed to unregister display reconfiguration callback")
-        self.client = None
-
-    def ready(self) -> None:
-        if EVENT_LISTENER:
-            with log.trap_error("Error setting up OSX event listener"):
-                self.setup_event_listener()
-
-    def setup_event_listener(self) -> None:
-        log(f"setup_event_listener() client={self.client}")
-        if self.client:
-            from xpra.platform.darwin.events import get_app_delegate
-            delegate = get_app_delegate()
-            log(f"setup_event_listener() delegate={delegate}")
-            delegate.add_handler("suspend", self.client.suspend)
-            delegate.add_handler("resume", self.client.resume)
-            delegate.add_handler("deiconify", self.client.deiconify_windows)
-        r = CGDisplayRegisterReconfigurationCallback(self.display_change, self)
-        if r != 0:
-            log.warn("Warning: failed to register display reconfiguration callback")
-
-    def display_change(self, display, flags, userinfo) -> None:
-        log("display_change%s", (display, flags, userinfo))
-        c = self.client
-        # The display mode has changed
-        # opengl windows may need to be re-created since the GPU may have changed:
-        if (flags & kCGDisplaySetModeFlag) and c and c.opengl_enabled:
-            c.reinit_windows()
-
-    def check_display(self) -> bool:
-        log("check_display()")
-        try:
-            c = self.client
-            asleep = None
-            if not can_access_display():
-                asleep = True
-            else:
-                did = CG.CGMainDisplayID()
-                log("check_display() CGMainDisplayID()=%#x", did)
-                if did and c:
-                    asleep = bool(CG.CGDisplayIsAsleep(did))
-                    log("check_display() CGDisplayIsAsleep(%#x)=%s", did, asleep)
-            if c and asleep is not None and self.display_is_asleep != asleep:
-                self.display_is_asleep = asleep
-                if asleep:
-                    c.suspend()
-                else:
-                    c.resume()
-            return True
-        except Exception:
-            log.error("Error checking display sleep status", exc_info=True)
-            self.check_display_timer = 0
-            return False
-
-    def run(self) -> ExitValue:
-        # this is for running standalone
-        log("starting console event loop")
-        self.event_loop_started = True
-        import PyObjCTools.AppHelper as AppHelper
-        AppHelper.runConsoleEventLoop(installInterrupt=True)
-        # when running from the GTK main loop, we rely on another part of the code
-        # to run the event loop for us
-        return 0
-
-    def stop(self) -> None:
-        if self.event_loop_started:
-            self.event_loop_started = False
-            import PyObjCTools.AppHelper as AppHelper
-            AppHelper.stopEventLoop()
-
-
-def main() -> ExitValue:
-    from xpra.platform import program_context
-    with program_context("OSX Extras"):
-        log.enable_debug()
-        ce = ClientExtras(None, None)
-        ce.check_display()
-        ce.ready()
-        return ce.run()
-
-
-if __name__ == "__main__":
-    main()
